@@ -280,9 +280,12 @@ class LaunchPad(FWSerializable):
 
     def defuse_fw(self, fw_id):
         allowed_states = ['DEFUSED', 'WAITING', 'READY', 'FIZZLED']
-        return self.fireworks.find_and_modify({'fw_id': fw_id, 'state': {'$in': allowed_states}},
+        f = self.fireworks.find_and_modify({'fw_id': fw_id, 'state': {'$in': allowed_states}},
                                               {'$set': {'state': 'DEFUSED'}})
 
+        self._refresh_wf(self.get_wf_by_fw_id(fw_id), fw_id)
+        return f
+
     def reignite_fw(self, fw_id):
         f = self.fireworks.find_and_modify({'fw_id': fw_id, 'state': 'DEFUSED'},
                                            {'$set': {'state': 'WAITING'}})
@@ -295,11 +298,28 @@ class LaunchPad(FWSerializable):
         for fw in wf.fws:
             self.defuse_fw(fw.fw_id)
 
+        self._refresh_wf(self.get_wf_by_fw_id(fw_id), fw_id)
+
+
     def reignite_wf(self, fw_id):
         wf = self.get_wf_by_fw_id(fw_id)
         for fw in wf.fws:
             self.reignite_fw(fw.fw_id)
 
+    def archive_wf(self, fw_id):
+        # first archive all the launches, so they are not used in duplicate checks
+        wf = self.get_wf_by_fw_id(fw_id)
+        fw_ids = [f.fw_id for f in wf.fws]
+        for fw_id in fw_ids:
+            self.rerun_fw(fw_id)
+
+        # second set the state of all FWs to ARCHIVED
+        wf = self.get_wf_by_fw_id(fw_id)
+        for fw in wf.fws:
+            self.fireworks.find_and_modify({'fw_id': fw.fw_id}, {'$set': {'state': 'ARCHIVED'}})
+
+        self._refresh_wf(self.get_wf_by_fw_id(fw_id), fw_id)
+
     def _restart_ids(self, next_fw_id, next_launch_id):
         """
         (internal method) Used to reset id counters
@@ -592,27 +612,5 @@ class LaunchPad(FWSerializable):
 
     def _upsert_launch(self, m_launch):
         # Do a confirmed write of Launch
-        self.launches.find_and_modify({'launch_id': m_launch.launch_id}, m_launch.to_db_dict(), upsert=True)
-
-        """
-        # confirm write
-        # I can't believe this is actually necessary (and yes, it appears to be necessary)
-        nloops = 0
-        while not self.launches.find_one({'launch_id': l_id, 'state': m_launch.state}):
-            self.m_logger.debug('Waiting for a delayed write of launch_id: {} ...'.format(l_id))
-            nloops += 1
-            if nloops == 80:
-                if m_launch.state == 'FIZZLED':
-                    # We're unable to mark the launch as FIZZLED
-                    self.m_logger.critical('UNABLE to mark launch_id: {} as fizzled!'.format(l_id))
-                    break
-                    # mark the launch as FIZZLED because we're unable to update its state...
-                self.m_logger.error(
-                    'FIZZLED launch id: {} because could not confirm write!!'.format(l_id))
-                self.mark_fizzled(l_id)
-                break
-            if nloops % 40 == 0:
-                self.m_logger.warning('Fixing a lost write of launch_id: {}'.format(l_id))
-                self.launches.find_and_modify({'launch_id': l_id}, m_launch.to_db_dict())
-            time.sleep(4)
-        """
\ No newline at end of file
+        # TODO: this no longer needs to be its own function (much was removed)
+        self.launches.find_and_modify({'launch_id': m_launch.launch_id}, m_launch.to_db_dict(), upsert=True)
\ No newline at end of file
